import { ɵɵdefineInjectable, ɵɵinject, ComponentFactoryResolver, ApplicationRef, INJECTOR, Injectable, Injector, Component, EventEmitter, Input, Output, ElementRef, Pipe, NgModule } from '@angular/core';
import { Subject, BehaviorSubject } from 'rxjs';
import calendarize from 'calendarize';
import { hex } from 'wcag-contrast';
import { format, getYear, getMonth, getDate, getDay } from 'date-fns';
import { MatIconModule } from '@angular/material/icon';
import { CommonModule } from '@angular/common';
import { MatButtonModule } from '@angular/material/button';

class NgbMaterialDatepickerInjector {
    constructor(_parentInjector, _additionalTokens) {
        this._parentInjector = _parentInjector;
        this._additionalTokens = _additionalTokens;
    }
    get(token, notFoundValue, flags) {
        const value = this._additionalTokens.get(token);
        if (value) {
            return value;
        }
        return this._parentInjector.get(token, notFoundValue);
    }
}

class NgbMaterialDatepickerConfig {
}

class NgbMaterialDatepickerRef {
    constructor() {
        /**
         * 閉じた時に値を渡すためのSubject
         * @private
         */
        this._afterClose = new Subject();
        /**
         * 閉じた時の値を受け取るためのObservable
         */
        this.afterClose = this._afterClose.asObservable();
    }
    /**
     * Datepickerを閉じる。
     * @param result
     */
    close(result) {
        this._afterClose.next(result);
    }
}

class DynamicallyComponentService {
    constructor(componentFactoryResolver, applicationRef, injector) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.applicationRef = applicationRef;
        this.injector = injector;
    }
    get dynamicComponentRef() {
        if (!this._dynamicComponentRef) {
            throw new Error('Component has not been created');
        }
        return this._dynamicComponentRef;
    }
    /**
     * 動的コンポーネントをdocument.body配下に追加する。
     */
    appendToApplication(type, config) {
        const datepickerRef = new NgbMaterialDatepickerRef();
        const componentRef = this.createComponentRef(type, config, datepickerRef);
        this.applicationRef.attachView(componentRef.hostView);
        this._attachComponentToDocumentBody(componentRef);
        this._dynamicComponentRef = componentRef;
        // 様々な箇所で呼ばれるDatepickerRef.afterCloseを検知し、Datepickerを閉じて購読を解除する。
        const sub = datepickerRef.afterClose.subscribe(() => {
            this._removeFromApplication();
            sub.unsubscribe();
        });
        return datepickerRef;
    }
    /**
     * 動的コンポーネントをdocument.bodyから削除する。
     * @private
     */
    _removeFromApplication() {
        if (!this._dynamicComponentRef) {
            throw new Error('Component has not been created');
        }
        this.applicationRef.detachView(this._dynamicComponentRef.hostView);
        this._dynamicComponentRef.destroy();
    }
    /**
     * ComponentRefを作成する。
     * @param componentType
     * @param config
     * @param datepickerRef
     * @private
     * @return {ComponentRef}
     */
    createComponentRef(componentType, config, datepickerRef) {
        const map = new WeakMap();
        map.set(NgbMaterialDatepickerConfig, config);
        map.set(NgbMaterialDatepickerRef, datepickerRef);
        const componentFactory = this.componentFactoryResolver.resolveComponentFactory(componentType);
        return componentFactory.create(new NgbMaterialDatepickerInjector(this.injector, map));
    }
    /**
     * ComponentRefをdocument.body配下に追加する。
     * @param componentRef
     * @private
     * @return {void}
     */
    _attachComponentToDocumentBody(componentRef) {
        const domElm = componentRef.hostView.rootNodes[0];
        document.body.appendChild(domElm);
    }
}
DynamicallyComponentService.ɵprov = ɵɵdefineInjectable({ factory: function DynamicallyComponentService_Factory() { return new DynamicallyComponentService(ɵɵinject(ComponentFactoryResolver), ɵɵinject(ApplicationRef), ɵɵinject(INJECTOR)); }, token: DynamicallyComponentService, providedIn: "root" });
DynamicallyComponentService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
DynamicallyComponentService.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: ApplicationRef },
    { type: Injector }
];

class NgbMaterialDatepickerOverlayComponent {
    constructor(_dynamicallyComponent, _datepickerRef) {
        this._dynamicallyComponent = _dynamicallyComponent;
        this._datepickerRef = _datepickerRef;
    }
    ngAfterViewInit() { }
    ngOnDestroy() { }
    /**
     * Overlayがクリックされた。
     * @param {MouseEvent} event
     */
    onOverlayClick(event) {
        this._datepickerRef.close();
    }
    /**
     * ダイアログがクリックされた。
     * ※ダイアログクリックでもOverlayのクリック扱いとなってしまうため、イベントを止める。
     * @param {MouseEvent} event
     */
    onDialogClick(event) {
        event.stopPropagation();
    }
}
NgbMaterialDatepickerOverlayComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-ngb-material-datepicker-container',
                template: "<div class=\"overlay\" (click)=\"onOverlayClick($event)\">\n    <div class=\"dialog\" (click)=\"onDialogClick($event)\">\n        <lib-ngb-material-datepicker></lib-ngb-material-datepicker>\n    </div>\n</div>\n",
                styles: [".overlay{position:fixed;top:0;bottom:0;left:0;right:0;background:rgba(0,0,0,.7);align-items:center;justify-content:center}.dialog,.overlay{display:flex;flex-direction:column}.dialog{background-color:#fff;width:300px;height:520px}"]
            },] }
];
NgbMaterialDatepickerOverlayComponent.ctorParameters = () => [
    { type: DynamicallyComponentService },
    { type: NgbMaterialDatepickerRef }
];

class NgbMaterialDatepickerService {
    constructor(_dynamicallyComponent) {
        this._dynamicallyComponent = _dynamicallyComponent;
    }
    /**
     * Datepickerを開く。
     */
    open(config) {
        return this._dynamicallyComponent.appendToApplication(NgbMaterialDatepickerOverlayComponent, config);
    }
}
NgbMaterialDatepickerService.ɵprov = ɵɵdefineInjectable({ factory: function NgbMaterialDatepickerService_Factory() { return new NgbMaterialDatepickerService(ɵɵinject(DynamicallyComponentService)); }, token: NgbMaterialDatepickerService, providedIn: "root" });
NgbMaterialDatepickerService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
NgbMaterialDatepickerService.ctorParameters = () => [
    { type: DynamicallyComponentService }
];

class DateTableService {
    constructor() { }
    /**
     * DateTableを作成する。
     * @param {undefined|Date} date
     * @return {DateTable}
     */
    create(date) {
        if (date == null) {
            return calendarize(new Date());
        }
        return calendarize(date);
    }
}
DateTableService.ɵprov = ɵɵdefineInjectable({ factory: function DateTableService_Factory() { return new DateTableService(); }, token: DateTableService, providedIn: "root" });
DateTableService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
DateTableService.ctorParameters = () => [];

// @dynamic
class A11yColor {
    /**
     * 渡されたカラーコードの形式が正しいか判定する。
     * ※#FFFFFFの形式のみ有効。またカラーコードがundefined等のときの判定は、
     * 使用側によって変わるため、ここでは行わない。
     * @param colorCode
     */
    static validColorCode(colorCode) {
        return this.COLOR_CODE_PATTERN.test(colorCode);
    }
    /**
     * 背景色に適した文字色を取得する。
     * @param backgroundColor
     */
    static getTextColor(backgroundColor) {
        const darkRatio = hex(backgroundColor, this.TEXT_COLOR_BLACK);
        const lightRatio = hex(backgroundColor, this.TEXT_COLOR_WHITE);
        return lightRatio < darkRatio ? this.TEXT_COLOR_BLACK : this.TEXT_COLOR_WHITE;
    }
}
A11yColor.COLOR_CODE_PATTERN = /^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$/i;
A11yColor.TEXT_COLOR_BLACK = '#000000';
A11yColor.TEXT_COLOR_WHITE = '#FFFFFF';

class NgbMaterialDatepickerPresenterService {
    constructor() { }
    /**
     * 日付の背景色を初期化する
     * @param dateColor
     */
    initializeDateColor(dateColor) {
        if (dateColor == null) {
            return '#689F37';
        }
        if (!A11yColor.validColorCode(dateColor)) {
            return '#689F37';
        }
        return dateColor;
    }
    /**
     * ヘッダー の背景色を初期化する
     * @param headerColor
     */
    initializeHeaderColor(headerColor) {
        if (headerColor == null) {
            return '#8CC24A';
        }
        if (!A11yColor.validColorCode(headerColor)) {
            return '#8CC24A';
        }
        return headerColor;
    }
    /**
     * 文字色を取得する。文字色が指定されていない場合は、背景色とのコントラスト比から適切な文字色を取得する。
     * @param backgroundColor
     * @param textColor
     */
    getTextColor(backgroundColor, textColor) {
        if (textColor == null) {
            return A11yColor.getTextColor(backgroundColor);
        }
        if (!A11yColor.validColorCode(textColor)) {
            throw new Error('Background Color is invalid.');
        }
        return textColor;
    }
}
NgbMaterialDatepickerPresenterService.ɵprov = ɵɵdefineInjectable({ factory: function NgbMaterialDatepickerPresenterService_Factory() { return new NgbMaterialDatepickerPresenterService(); }, token: NgbMaterialDatepickerPresenterService, providedIn: "root" });
NgbMaterialDatepickerPresenterService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
NgbMaterialDatepickerPresenterService.ctorParameters = () => [];

class DateService {
    constructor() { }
    /**
     * 日付を2桁の0埋めする。
     * @param date
     */
    fillWithZeros(date) {
        const dateString = '' + date;
        return dateString.padStart(2, '0');
    }
    /**
     * 曜日エイリアスを取得する。
     * @param date
     */
    getDay(date) {
        const { day } = this._getYearMonthDateDay(date);
        return day;
    }
    /**
     * 年月日, 曜日を取得する。
     * @param {undefined|Date} date
     * @return {YearMonthDateDay}
     */
    getYearMonthDateDay(date) {
        if (date == null) {
            return this._getYearMonthDateDay(new Date());
        }
        return this._getYearMonthDateDay(date);
    }
    /**
     * 年月日からDateオブジェクトを作成する。
     * @param source
     */
    getDateFromYearMonthDate(source) {
        const { year, month: zeroBeginningMonth, date } = source;
        return new Date(year, zeroBeginningMonth, date);
    }
    /**
     * 月を0始まりの形式に変換する。
     * ※1月であれば0, 12月であれば11に変換する。
     * @param month
     */
    convertMonthToZeroStart(month) {
        if (month === 0) {
            return 1;
        }
        if (month === 12) {
            return 11;
        }
        return month - 1;
    }
    /**
     * 年月日を指定された形式の日付文字列にする。
     * @param dateFormat
     * @param source
     */
    format(dateFormat, source) {
        const { year, month: zeroBeginningMonth, date } = source;
        if (year == null || zeroBeginningMonth == null || date == null) {
            throw new Error('Source value is null.');
        }
        return format(new Date(year, zeroBeginningMonth, date), dateFormat);
    }
    /**
     * 年月日, 曜日を取得する。
     * @param {Date} sourceDate
     * @private
     * @return {YearMonthDateDay}
     */
    _getYearMonthDateDay(sourceDate) {
        const year = getYear(sourceDate);
        // 月は0から始まるため
        const month = getMonth(sourceDate) + 1;
        const date = getDate(sourceDate);
        const day = getDay(sourceDate);
        return { year, month, date, day };
    }
}
DateService.ɵprov = ɵɵdefineInjectable({ factory: function DateService_Factory() { return new DateService(); }, token: DateService, providedIn: "root" });
DateService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
DateService.ctorParameters = () => [];

const DEFAULT_VALUE = {
    year: 0,
    month: 0,
    date: 0,
    day: 0,
};
class DateState {
    constructor(_date) {
        this._date = _date;
        this._dateState = new BehaviorSubject(DEFAULT_VALUE);
        this.dateState$ = this._dateState.asObservable();
    }
    /**
     * 現在の値を取得する。
     */
    get currentValue() {
        const currentValue = this._dateState.getValue();
        if (currentValue == null) {
            throw new Error('DateState currentValue is null.');
        }
        return currentValue;
    }
    /**
     * 現在の日付状態から日付文字列を取得する。
     * @param dateFormat
     */
    getDateStringFromCurrentState(dateFormat = 'yyyy-MM-dd HH:mm:ss') {
        const { year, month, date } = this.currentValue;
        const monthBeginningZero = this._date.convertMonthToZeroStart(month);
        return this._date.format(dateFormat, { year, month: monthBeginningZero, date });
    }
    /**
     * DateStateを更新する。
     * @param updateValue
     */
    update(updateValue) {
        const currentValue = this.currentValue;
        this._dateState.next(Object.assign(Object.assign({}, currentValue), updateValue));
    }
}
DateState.ɵprov = ɵɵdefineInjectable({ factory: function DateState_Factory() { return new DateState(ɵɵinject(DateService)); }, token: DateState, providedIn: "root" });
DateState.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
DateState.ctorParameters = () => [
    { type: DateService }
];

class NgbMaterialDatepickerComponent {
    constructor(_ngbDatepickerService, _presenter, _dataTable, _date, _dateState, _config, _datepickerRef) {
        this._ngbDatepickerService = _ngbDatepickerService;
        this._presenter = _presenter;
        this._dataTable = _dataTable;
        this._date = _date;
        this._dateState = _dateState;
        this._config = _config;
        this._datepickerRef = _datepickerRef;
        this.displayWeek = ['日', '月', '火', '水', '木', '金', '土'];
        this.dateState$ = this._dateState.dateState$;
        this.dataTable = [];
        this.headerColor = '';
        this.dateColor = '';
        this.headerTextColor = '';
        this.dateTextColor = '';
    }
    ngOnInit() {
        const { headerColor, dateColor, headerTextColor, dateTextColor, initializeValue, } = this._config;
        // 各Styleを設定
        this.headerColor = this._presenter.initializeHeaderColor(headerColor);
        this.dateColor = this._presenter.initializeDateColor(dateColor);
        this.headerTextColor = this._presenter.getTextColor(this.headerColor, headerTextColor);
        this.dateTextColor = this._presenter.getTextColor(this.dateColor, dateTextColor);
        // 日付テーブルを作成する。
        this.dataTable = this._dataTable.create(initializeValue);
        // 初期値を設定する。
        const initializeDate = this._date.getYearMonthDateDay(initializeValue);
        this._dateState.update(initializeDate);
    }
    /**
     * 閉じるがクリックされた。
     */
    clickClose() {
        this._datepickerRef.close();
    }
    /**
     * OKがクリックされた。
     */
    clickOk() {
        const { outputFormat } = this._config;
        const result = this._dateState.getDateStringFromCurrentState(outputFormat);
        this._datepickerRef.close(result);
    }
    /**
     * Cancelがクリックされた。
     */
    clickCancel() {
        this._datepickerRef.close();
    }
    /**
     * 日付が選択された。
     * @param date
     */
    selectDate(date) {
        const { year, month } = this._dateState.currentValue;
        const zeroBeginningMonth = this._date.convertMonthToZeroStart(month);
        const day = this._date.getDay(this._date.getDateFromYearMonthDate({ year, month: zeroBeginningMonth, date }));
        this._dateState.update({ date, day });
    }
    /**
     * 前月を表示する。
     * @param month
     */
    lastMonth(month) {
        const updateMonth = month !== 1 ? month - 1 : 12;
        this._dateState.update({ month: updateMonth });
        this._updateDateTable();
    }
    /**
     * 次月を表示する。
     * @param month
     */
    nextMonth(month) {
        const updateMonth = month !== 12 ? month + 1 : 1;
        this._dateState.update({ month: updateMonth });
        this._updateDateTable();
    }
    /**
     * 翌年を表示する。
     * @param year
     */
    lastYear(year) {
        this._dateState.update({ year: year - 1 });
        this._updateDateTable();
    }
    /**
     * 去年を表示する。
     * @param year
     */
    nextYear(year) {
        this._dateState.update({ year: year + 1 });
        this._updateDateTable();
    }
    /**
     * DateTableを更新する。
     * @private
     */
    _updateDateTable() {
        const { year, month, date } = this._dateState.currentValue;
        const convertMonthToZeroStart = this._date.convertMonthToZeroStart(month);
        const yearMonthDate = this._date.getDateFromYearMonthDate({
            year,
            month: convertMonthToZeroStart,
            date,
        });
        this.dataTable = this._dataTable.create(yearMonthDate);
    }
}
NgbMaterialDatepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-ngb-material-datepicker',
                template: "<ng-container *ngIf=\"dateState$ | async as dateState\">\n    <lib-header\n        class=\"header\"\n        [days]=\"dateState.day\"\n        [backgroundColor]=\"headerColor\"\n        [textColor]=\"headerTextColor\"\n        (onClickClose)=\"clickClose()\"\n    ></lib-header>\n\n    <lib-year-month-date-area\n        class=\"year-month-date-area\"\n        [backgroundColor]=\"dateColor\"\n        [textColor]=\"dateTextColor\"\n        [selectedYear]=\"dateState.year\"\n        [selectedMonth]=\"dateState.month\"\n        [selectedDate]=\"dateState.date\"\n        (onLastMonth)=\"lastMonth($event)\"\n        (onNextMonth)=\"nextMonth($event)\"\n        (onLastYear)=\"lastYear($event)\"\n        (onNextYear)=\"nextYear($event)\"\n    ></lib-year-month-date-area>\n\n    <lib-calendar\n        class=\"calendar\"\n        [selectedBackgroundColor]=\"dateColor\"\n        [selectedTextColor]=\"dateTextColor\"\n        [displayWeek]=\"displayWeek\"\n        [selectedYear]=\"dateState.year\"\n        [selectedMonth]=\"dateState.month\"\n        [selectedDate]=\"dateState.date\"\n        [dateTable]=\"dataTable\"\n        (onSelectDate)=\"selectDate($event)\"\n    ></lib-calendar>\n\n    <lib-footer class=\"footer\" (onClickOk)=\"clickOk()\" (onClickCancel)=\"clickCancel()\"></lib-footer>\n</ng-container>\n",
                styles: [""]
            },] }
];
NgbMaterialDatepickerComponent.ctorParameters = () => [
    { type: NgbMaterialDatepickerService },
    { type: NgbMaterialDatepickerPresenterService },
    { type: DateTableService },
    { type: DateService },
    { type: DateState },
    { type: NgbMaterialDatepickerConfig },
    { type: NgbMaterialDatepickerRef }
];

class HeaderComponent {
    constructor() {
        this.days = 0;
        this.backgroundColor = '#689F37';
        this.textColor = '#FFFFFF';
        this.onClickClose = new EventEmitter();
        this.colorStyle = {
            'background-color': this.backgroundColor,
            color: this.textColor,
        };
    }
    ngOnInit() {
        this.colorStyle = {
            'background-color': this.backgroundColor,
            color: this.textColor,
        };
    }
    clickClose() {
        this.onClickClose.emit();
    }
}
HeaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-header',
                template: "<header class=\"header\" [ngStyle]=\"colorStyle\">\n    <div class=\"header__days\">{{ days | convertWeekAlias }}</div>\n    <div class=\"header__close\" (click)=\"clickClose()\">\n        <mat-icon>close</mat-icon>\n    </div>\n</header>\n",
                styles: [":host{display:block}:host .header{position:relative;padding:.2rem 0;text-align:center}:host .header .header__days{width:100%}:host .header .header__close{position:absolute;top:.05rem;right:.25rem;cursor:default;height:24px}"]
            },] }
];
HeaderComponent.ctorParameters = () => [];
HeaderComponent.propDecorators = {
    days: [{ type: Input }],
    backgroundColor: [{ type: Input }],
    textColor: [{ type: Input }],
    onClickClose: [{ type: Output }]
};

class YearMonthDateAreaComponent {
    constructor() {
        this.selectedMonth = 0;
        this.selectedDate = 0;
        this.selectedYear = 0;
        this.backgroundColor = '#8CC24A';
        this.textColor = '#FFFFFF';
        this.onLastMonth = new EventEmitter();
        this.onNextMonth = new EventEmitter();
        this.onLastYear = new EventEmitter();
        this.onNextYear = new EventEmitter();
        this.colorStyle = {
            'background-color': this.backgroundColor,
            color: this.textColor,
        };
    }
    ngOnInit() {
        this.colorStyle = {
            'background-color': this.backgroundColor,
            color: this.textColor,
        };
    }
    lastMonth(month) {
        this.onLastMonth.emit(month);
    }
    nextMonth(month) {
        this.onNextMonth.emit(month);
    }
    lastYear(year) {
        this.onLastYear.emit(year);
    }
    nextYear(year) {
        this.onNextYear.emit(year);
    }
}
YearMonthDateAreaComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-year-month-date-area',
                template: "<div class=\"year-month-date-area\" [ngStyle]=\"colorStyle\">\n    <lib-select-month\n        [month]=\"selectedMonth\"\n        (onClickLastMonth)=\"lastMonth($event)\"\n        (onClickNextMonth)=\"nextMonth($event)\"\n    ></lib-select-month>\n    <lib-select-date>{{ selectedDate | fillDateWithZeros }}</lib-select-date>\n    <lib-select-year\n        [year]=\"selectedYear\"\n        (onClickLastYear)=\"lastYear($event)\"\n        (onClickNextYear)=\"nextYear($event)\"\n    ></lib-select-year>\n</div>\n",
                styles: [":host{display:block}:host .year-month-date-area{padding:.4rem 1rem}"]
            },] }
];
YearMonthDateAreaComponent.ctorParameters = () => [];
YearMonthDateAreaComponent.propDecorators = {
    selectedMonth: [{ type: Input }],
    selectedDate: [{ type: Input }],
    selectedYear: [{ type: Input }],
    backgroundColor: [{ type: Input }],
    textColor: [{ type: Input }],
    onLastMonth: [{ type: Output }],
    onNextMonth: [{ type: Output }],
    onLastYear: [{ type: Output }],
    onNextYear: [{ type: Output }]
};

class SelectMonthComponent {
    constructor() {
        this.month = 0;
        this.onClickLastMonth = new EventEmitter();
        this.onClickNextMonth = new EventEmitter();
    }
    ngOnInit() { }
    lastMonth() {
        this.onClickLastMonth.emit(this.month);
    }
    nextMonth() {
        this.onClickNextMonth.emit(this.month);
    }
}
SelectMonthComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-select-month',
                template: "<div class=\"select-month\">\n    <div class=\"select-month__last-month\" (click)=\"lastMonth()\">\n        <mat-icon>chevron_left</mat-icon>\n    </div>\n    <div class=\"select-month__current-month\">{{ month }}\u6708</div>\n    <div class=\"select-month__next-month\" (click)=\"nextMonth()\">\n        <mat-icon>chevron_right</mat-icon>\n    </div>\n</div>\n",
                styles: [":host{display:block}:host .select-month{display:flex;justify-content:space-between;align-items:center}:host .select-month .select-month__last-month{height:24px;cursor:default}:host .select-month .select-month__current-month{font-size:1.25rem}:host .select-month .select-month__next-month{height:24px;cursor:default}"]
            },] }
];
SelectMonthComponent.ctorParameters = () => [];
SelectMonthComponent.propDecorators = {
    month: [{ type: Input }],
    onClickLastMonth: [{ type: Output }],
    onClickNextMonth: [{ type: Output }]
};

class SelectYearComponent {
    constructor() {
        this.year = 0;
        this.onClickLastYear = new EventEmitter();
        this.onClickNextYear = new EventEmitter();
    }
    ngOnInit() { }
    lastYear() {
        this.onClickLastYear.emit(this.year);
    }
    nextYear() {
        this.onClickNextYear.emit(this.year);
    }
}
SelectYearComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-select-year',
                template: "<div class=\"select-year\">\n    <div class=\"select-year__last-year\" (click)=\"lastYear()\">\n        <mat-icon>chevron_left</mat-icon>\n    </div>\n    <div class=\"select-year__current-year\">{{ year }}</div>\n    <div class=\"select-year__next-year\" (click)=\"nextYear()\">\n        <mat-icon>chevron_right</mat-icon>\n    </div>\n</div>\n",
                styles: [":host{display:block}:host .select-year{display:flex;justify-content:space-between;align-items:center}:host .select-year .select-year__last-year{height:24px;cursor:default}:host .select-year .select-year__current-year{font-size:1.25rem}:host .select-year .select-year__next-year{height:24px;cursor:default}"]
            },] }
];
SelectYearComponent.ctorParameters = () => [];
SelectYearComponent.propDecorators = {
    year: [{ type: Input }],
    onClickLastYear: [{ type: Output }],
    onClickNextYear: [{ type: Output }]
};

class SelectDateComponent {
    constructor() { }
    ngOnInit() { }
}
SelectDateComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-select-date',
                template: `<ng-content></ng-content>`,
                styles: [`
            :host {
                display: flex;
                justify-content: center;
                align-items: center;
                font-size: 45px;
                height: 45px;
            }
        `]
            },] }
];
SelectDateComponent.ctorParameters = () => [];

class DateTableComponent {
    constructor(thisEleRef) {
        this.thisEleRef = thisEleRef;
        this.displayWeek = ['', '', '', '', '', '', ''];
        this.dateTable = [];
        this.selectedDate = 0;
        this.selectedBackgroundColor = '#8cc24a';
        this.selectedTextColor = '#FFFFFF';
        this.onSelectDate = new EventEmitter();
    }
    ngAfterContentInit() {
        this.updateSelectedColor();
    }
    selectDate(date) {
        this.onSelectDate.emit(date);
    }
    updateSelectedColor() {
        this.thisEleRef.nativeElement.style.setProperty('--selected-background-color', this.selectedBackgroundColor);
        this.thisEleRef.nativeElement.style.setProperty('--selected-color', this.selectedTextColor);
    }
}
DateTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-date-table',
                template: "<div class=\"week\" *ngFor=\"let week of dateTable\">\n    <div class=\"week__date-wrapper\" *ngFor=\"let date of week\">\n        <div\n            class=\"week__date\"\n            [ngClass]=\"{ selected: date | isSelectedDate: selectedDate }\"\n            (click)=\"selectDate(date)\"\n        >\n            {{ date | fillDateWithZeros }}\n        </div>\n    </div>\n</div>\n",
                styles: [":host{display:block;--selected-background-color:#8cc24a;--selected-color:#fff}:host .selected{background-color:var(--selected-background-color);color:var(--selected-color);border-radius:50%}:host .week{display:flex}:host .week .week__date-wrapper{width:calc(100% / 7);padding:.3rem}:host .week .week__date{text-align:center;line-height:1.85rem;cursor:default}"]
            },] }
];
DateTableComponent.ctorParameters = () => [
    { type: ElementRef }
];
DateTableComponent.propDecorators = {
    displayWeek: [{ type: Input }],
    dateTable: [{ type: Input }],
    selectedDate: [{ type: Input }],
    selectedBackgroundColor: [{ type: Input }],
    selectedTextColor: [{ type: Input }],
    onSelectDate: [{ type: Output }]
};

class CalendarComponent {
    constructor() {
        this.selectedBackgroundColor = '';
        this.selectedTextColor = '';
        this.selectedDate = 0;
        this.selectedMonth = 0;
        this.selectedYear = 0;
        this.displayWeek = ['', '', '', '', '', '', ''];
        this.dateTable = [];
        this.onSelectDate = new EventEmitter();
    }
    ngOnInit() { }
    selectDate(date) {
        this.onSelectDate.emit(date);
    }
}
CalendarComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-calendar',
                template: "<lib-year-month class=\"year-month\">{{ selectedMonth }}\u6708&nbsp;{{ selectedYear }}</lib-year-month>\n\n<lib-week class=\"week\" [displayWeek]=\"displayWeek\"></lib-week>\n\n<lib-date-table\n    class=\"date-table\"\n    [selectedBackgroundColor]=\"selectedBackgroundColor\"\n    [selectedTextColor]=\"selectedTextColor\"\n    [displayWeek]=\"displayWeek\"\n    [dateTable]=\"dateTable\"\n    [selectedDate]=\"selectedDate\"\n    (onSelectDate)=\"selectDate($event)\"\n></lib-date-table>\n",
                styles: [":host{display:block;padding:1rem}:host .week{margin-top:1rem}"]
            },] }
];
CalendarComponent.ctorParameters = () => [];
CalendarComponent.propDecorators = {
    selectedBackgroundColor: [{ type: Input }],
    selectedTextColor: [{ type: Input }],
    selectedDate: [{ type: Input }],
    selectedMonth: [{ type: Input }],
    selectedYear: [{ type: Input }],
    displayWeek: [{ type: Input }],
    dateTable: [{ type: Input }],
    onSelectDate: [{ type: Output }]
};

class YearMonthComponent {
    constructor() { }
    ngOnInit() { }
}
YearMonthComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-year-month',
                template: ` <ng-content></ng-content> `,
                styles: [`
            :host {
                display: flex;
                justify-content: center;
                align-items: center;
            }
        `]
            },] }
];
YearMonthComponent.ctorParameters = () => [];

class WeekComponent {
    constructor() {
        this.displayWeek = ['', '', '', '', '', '', ''];
    }
    ngOnInit() { }
}
WeekComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-week',
                template: ` <span class="days" *ngFor="let day of displayWeek">{{ day }}</span> `,
                styles: [`
            :host {
                display: flex;
                justify-content: space-between;
                align-items: center;
                color: #757575;
            }
        `,
                    `
            .days {
                width: calc(100% / 7);
                text-align: center;
            }
        `]
            },] }
];
WeekComponent.ctorParameters = () => [];
WeekComponent.propDecorators = {
    displayWeek: [{ type: Input }]
};

class FillDateWithZerosPipe {
    constructor(_date) {
        this._date = _date;
    }
    /**
     * 数値の日付を2桁の0埋めをした文字列日付に変換する
     * @param {number} date
     * @return {string}
     */
    transform(date) {
        if (date === 0) {
            return '';
        }
        return this._date.fillWithZeros(date);
    }
}
FillDateWithZerosPipe.decorators = [
    { type: Pipe, args: [{
                name: 'fillDateWithZeros',
            },] }
];
FillDateWithZerosPipe.ctorParameters = () => [
    { type: DateService }
];

class IsSelectedDatePipe {
    /**
     * この日付は選択されている。
     * @param thisDate
     * @param selectedDate
     */
    transform(thisDate, selectedDate) {
        if (thisDate === 0) {
            return false;
        }
        return thisDate === selectedDate;
    }
}
IsSelectedDatePipe.decorators = [
    { type: Pipe, args: [{
                name: 'isSelectedDate',
            },] }
];

class FooterComponent {
    constructor() {
        this.onClickCancel = new EventEmitter();
        this.onClickOk = new EventEmitter();
    }
    ngOnInit() { }
    clickCancel() {
        this.onClickCancel.emit();
    }
    clickOk() {
        this.onClickOk.emit();
    }
}
FooterComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-footer',
                template: "<button mat-button (click)=\"clickCancel()\">CANCEL</button>\n<button mat-button class=\"ok-button\" (click)=\"clickOk()\">OK</button>\n",
                styles: [":host{display:flex;justify-content:flex-end;align-items:center;padding:0 1rem}:host .ok-button{margin-left:.5rem}"]
            },] }
];
FooterComponent.ctorParameters = () => [];
FooterComponent.propDecorators = {
    onClickCancel: [{ type: Output }],
    onClickOk: [{ type: Output }]
};

const JapaneseWeek = {
    0: '日曜日',
    1: '月曜日',
    2: '火曜日',
    3: '水曜日',
    4: '木曜日',
    5: '金曜日',
    6: '土曜日',
};

class ConvertWeekAliasPipe {
    /**
     * 曜日エイリアスから日本の曜日を取得する
     * @param weekAlias
     */
    transform(weekAlias) {
        return JapaneseWeek[weekAlias];
    }
}
ConvertWeekAliasPipe.decorators = [
    { type: Pipe, args: [{
                name: 'convertWeekAlias',
            },] }
];

class NgbMaterialDatepickerModule {
}
NgbMaterialDatepickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NgbMaterialDatepickerComponent,
                    NgbMaterialDatepickerOverlayComponent,
                    HeaderComponent,
                    YearMonthDateAreaComponent,
                    SelectMonthComponent,
                    SelectYearComponent,
                    SelectDateComponent,
                    DateTableComponent,
                    CalendarComponent,
                    YearMonthComponent,
                    WeekComponent,
                    FillDateWithZerosPipe,
                    IsSelectedDatePipe,
                    FooterComponent,
                    ConvertWeekAliasPipe,
                ],
                imports: [CommonModule, MatIconModule, MatButtonModule],
                exports: [],
            },] }
];

/*
 * Public API Surface of ngb-material-datepicker
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgbMaterialDatepickerComponent, NgbMaterialDatepickerModule, NgbMaterialDatepickerService, DynamicallyComponentService as ɵa, NgbMaterialDatepickerPresenterService as ɵb, DateTableService as ɵc, DateService as ɵd, DateState as ɵe, NgbMaterialDatepickerConfig as ɵf, NgbMaterialDatepickerRef as ɵg, NgbMaterialDatepickerOverlayComponent as ɵh, HeaderComponent as ɵi, YearMonthDateAreaComponent as ɵj, SelectMonthComponent as ɵk, SelectYearComponent as ɵl, SelectDateComponent as ɵm, DateTableComponent as ɵn, CalendarComponent as ɵo, YearMonthComponent as ɵp, WeekComponent as ɵq, FillDateWithZerosPipe as ɵr, IsSelectedDatePipe as ɵs, FooterComponent as ɵt, ConvertWeekAliasPipe as ɵu };
//# sourceMappingURL=ngb-material-datepicker.js.map
